@@ -4,12 +4,14 @@ __license__ = "MPL 2.0"
 
 import json
 import os
+
 import tunel.api
+from tunel.logger import logger
 
 
 def api_get(args, parser, extra, subparser):
     if not os.path.exists(args.socket):
-        sys.exit("Socket for tunel %s does not exist." % args.socket)
+        logger.exit("Socket for tunel %s does not exist." % args.socket)
     api = tunel.api.ApiConnection(args.socket)
     res = api.get(args.path)
     if args.json:
